#
# spec file for package php5-pear-Mail
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           php5-pear-Mail
%define pear_name  Mail
%define pear_sname mail
Summary:        Multiple interfaces for sending emails
License:        BSD-3-Clause and SUSE-PHP-2.02
Group:          Productivity/Networking/Web/Servers
Version:        1.2.0
Release:        21.1
BuildArch:      noarch
Url:            http://pear.php.net/package/%{pear_name}
Source:         %{pear_name}-%{version}.tgz

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  php >= 4.4.9
%if 0%{?sles_version} == 10
BuildRequires:  php-macros
%else
BuildRequires:  php-devel >= 4.4.9
%endif
BuildRequires:  php-pear >= 1.5.6
Requires:       php >= 4.4.9
Requires:       php-pear >= 1.5.6
# optional
Suggests:       php-pear-Net_SMTP >= 1.4.1

Provides:       php-pear-%{pear_name} pear-%{pear_name}
Provides:       pear-%{pear_sname} = %{version}
Provides:       php-pear-%{pear_sname} = %{version}
Provides:       php5-pear-%{pear_sname} = %{version}
Obsoletes:      pear-%{pear_sname} < %{version}
Obsoletes:      php-pear-%{pear_sname} < %{version}
Obsoletes:      php5-pear-%{pear_sname} < %{version}

%description
PEAR's Mail package defines an interface for implementing mailers under the PEAR
hierarchy. It also provides supporting functions useful to multiple mailer
backends. Currently supported backends include: PHP's native mail() function,
sendmail, and SMTP. This package also provides a RFC822 email address list
validation utility class.

%prep
%setup -c

%build

%install
%{__mv} package*.xml %{pear_name}-%{version}
cd %{pear_name}-%{version}
PHP_PEAR_PHP_BIN="$(which php) -d memory_limit=50m"
%{__pear} -v \
        -d doc_dir=/doc \
        -d bin_dir=%{_bindir} \
        -d data_dir=%{php_peardir}/data \
        install --offline --nodeps -R "%{buildroot}" package.xml

%{__install} -D -m 0644 package.xml %{buildroot}%{php_pearxmldir}/%{pear_name}.xml

%{__rm} -rf %{buildroot}/{doc,tmp}
%{__rm} -rf %{buildroot}%{php_peardir}/.{filemap,lock,registry,channels,depdb,depdblock}

cd ..

%php_pear_gen_filelist

%post
# on `rpm -ivh` PARAM is 1
# on `rpm -Uvh` PARAM is 2
if [ "$1" = "1" ]; then
  %{__pear} install --nodeps --soft --force --register-only %{php_pearxmldir}/%{pear_name}.xml
fi
if [ "$1" = "2" ]; then
  %{__pear} upgrade --offline --register-only %{php_pearxmldir}/%{pear_name}.xml
fi

%postun
# on `rpm -e` PARAM is 0
if [ "$1" = "0" ]; then
  %{__pear} uninstall --nodeps --ignore-errors --register-only pear.php.net/%{pear_name}
fi

%files -f %{name}.files
%defattr(-, root, root)

%changelog
* Mon May 19 2014 aj@ajaissle.de
- Generic spec cleanup
* Mon Feb  6 2012 cfarrell@suse.com
- license update: BSD-3-Clause and SUSE-PHP-2.02
  sendmail.php is PHP-2.02 licensed. There is no SPDX short name for this
  currently so use the SUSE proprietary prefix until it is pushed upstream
  to spdx.org
* Mon Jan 30 2012 cdenicolo@suse.com
- license update: BSD-3-Clause
  BSD-3-Clause
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Thu Jan 20 2011 chris@computersalat.de
- change to php_pear_gen_filelist macro
* Wed Jan 19 2011 chris@computersalat.de
- pkg rename php5-pear-Mail
- merge with php-pear-mail (dr for it)
- update to 1.2.0
  - Updated minimum dependencies (Net_SMTP, PEAR, PHP)
  - Doc Bug #15620 Licence change to BSD
  - Bug #13659 Mail parse error in special condition
  - Bug #16200 - Security hole allow to read/write Arbitrary File
  - _hasUnclosedQuotes() doesn't properly handle a double slash
    before an end quote (slusarz@curecanti.org, Bug #9137).
  - Make sure Net_SMTP is defined when calling getSMTPObject()
    directly (slusarz@curecanti.org, Bug #13772).
  - Add addServiceExtensionParameter() to the SMTP driver
    (slusarz@curecanti.org, Bug #13764).
  - Add a method to obtain the Net_SMTP object from the SMTP driver
    (slusarz@curecanti.org, Bug #13766).
  - more info see ChangeLog
    http://pear.php.net/package/Mail/download/All
* Sat May 30 2009 chris@computersalat.de
- fixed deps (removed)
  o because optional
  o Requires php-pear-Net_SMTP >= 1.1.0
* Sat May 30 2009 chris@computersalat.de
- fixed post script
* Thu May 21 2009 chris@computersalat.de
- beautify spec
  o new spec header
  o package rename due to package convention
  o removed php4 stuff, deps
  o added Provides and Obsoletes for old package names.
    This should not break deps
- added stuff to automatically create correct filelist
  o tested against Factory (1120)
  o opensuse >= 1100 complains about
    "directory not owned by package"
- some rpmlint stuff
* Tue Apr 10 2007 suse-tux@gmx.de
- now really fixed build for <= 1010
* Tue Feb 27 2007 suse-tux@gmx.de
- make it work on older suse versions again
- introduced rpm macros
* Thu Feb 22 2007 judas_iscariote@shorewall.net
- debuginfo packages makes no sense here.
- convert to new pear package installation format, still experimental and subject to change.
* Sun Oct 29 2006 suse-tux@gmx.de
- update to version 1.1.14
* Sat Jun 17 2006 suse-tux@gmx.de
- update to version 1.1.10
- made spec file portable for older/new suse-versions
- removed #usedforbuild, added %%clean-macro
- added rpmmacros (changed "mv" to "%%__mv" etc.)
- remove Packager-tag :)
* Sun Jun 11 2006 suse-tux@gmx.de
- built for 10.0 because it's missing there!
- added Packager-tag
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 mmarek@suse.de
- fix filelist, remove temporary files created by pear installer
- unify php5-pear-*.spec files
- increase php's memory_limit during installation (parsing
  xml needs more than default 8M sometimes)
* Mon Jan 16 2006 mmarek@suse.cz
- created package to satisfy horde dependencies
